
--
-- ls-modsource.com
-- @author  Benjamin Gerisch aka Geri-G
-- @date  08/05/2010
--

Attacher = {};

function Attacher.prerequisitesPresent(specializations)
    return true;
end;

function Attacher:load(xmlFile)
	self.GetVehiclesInRange = Attacher.GetVehiclesInRange;
	self.attachVehicles = Attacher.attachVehicles;
	self.detachVehicles = Attacher.detachVehicles;
	self.allowedJointTypes = {};
	self.attacherTransform = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.AttacherJoint#index"));
	self.attacherColl = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.AttacherJoint#root"));
	if self.attacherTransform ~= nil then	
		self.rotCheck = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.AttacherJoint#rotChecker"));
		if self.rotCheck == nil then
			self.rotCheck = getParent(self.attacherTransform);
		end;
		self.oldRotRotCheck = {getRotation(self.rotCheck)};
	end;
    local types = getXMLString(xmlFile, "vehicle.AttacherJoint#types");
    if types ~= nil then
        local types = Utils.splitString(" ", types);
        for k,v in pairs(types) do
			self.allowedJointTypes[v] = true;
        end;
    end;
	
	self.wheelsD = {};	
	local Parent = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.wheelTransform#index"));
	if Parent ~= nil then
		for i = 1, getNumOfChildren(Parent) do
			local index = getChildAt(Parent,i-1);
			if index ~= nil then
				self.wheelsD[i] = index;
			end;
		end;
	end;
	
	self.attachedImplementIndex = nil;
	self.attachedImplement = nil;
	self.oldP = nil;
end;

function Attacher:delete()

end;

function Attacher:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Attacher:keyEvent(unicode, sym, modifier, isDown)
end;
function Attacher:update(dt)
	if self:getIsActive() then	
		for i=1, table.getn(self.wheels) do
			local x,y,z = getRotation(self.wheels[i].repr);
			if self.wheelsD[i] ~= nil then
				local x1,y1,z1 = getRotation(self.wheelsD[i]);
				setRotation(self.wheelsD[i],x,y1,z1);
			end;
		end;
	end;
	if self:getIsActive() and self.attacherTransform ~= nil then	
		local obj = nil;
		if self.attachedImplementIndex == nil then
			obj = self:GetVehiclesInRange();
		else
			local x,y,z = getRotation(self.rotCheck);
			if x ~= self.oldRotRotCheck[1] then
				setJointFrame(self.attachedImplementIndex, 0, self.attacherTransform);
			end;
			self.oldRotRotCheck = {x,y,z};			
		end;
		if self:getIsActiveForInput() then
			if InputBinding.hasEvent(InputBinding.ATTACH) then
				if obj ~= nil and self.attachedImplementIndex == nil then
					self:attachVehicles(obj);
				else
					self:detachVehicles();
				end;
			end;
		end;
		if obj ~= nil then
			g_currentMission:addHelpButtonText(g_i18n:getText("HitachiAttach"), InputBinding.ATTACH);
		end;
	end;
end;

function Attacher:draw()

end;
function Attacher:onLeave()
	if self.attachedImplement ~= nil then
		self.attachedImplement:onDeactivate();
	end;
end;
function Attacher:attachVehicles(obj)
	if self.attacherTransform ~= nil  then 			
	
		--anhaengen
		local constr = JointConstructor:new();					
		constr:setActors(self.attacherColl, obj.attacherColl);
		constr:setJointTransforms(self.attacherTransform, obj.attacherJoint);
		for i=1, 3 do
			constr:setTranslationLimit(i-1, true, 0, 0);
			constr:setRotationLimit(i-1,0,0);	
		end;		

		self.attachedImplementIndex = constr:finalize();
		self.attachedImplement = obj;
		
		if obj.linked ~= nil then
			self.oldP = getParent(obj.linked);
			link(self.attacherTransform,obj.linked);
		end;
		
		if obj.onAttach ~= nil then
			obj:onAttach(self);
		end;
	end;
end;
function Attacher:detachVehicles()
	if self.attachedImplementIndex ~= nil then
		removeJoint(self.attachedImplementIndex);
		self.attachedImplementIndex = nil;
		if self.attachedImplement.onDetach ~= nil then
			self.attachedImplement:onDetach();
		end;
		if self.attachedImplement.linked ~= nil and self.oldP ~= nil then
			link(self.oldP ,self.attachedImplement.linked);
		end;
		self.attachedImplement = nil;
	end;
end;
function Attacher:GetVehiclesInRange()
	local nearestNode = nil;
	local nearestDistance = 2;
	local px, py, pz = getWorldTranslation(self.attacherTransform);
	
	for k,v in pairs(g_currentMission.vehicles) do
		if v ~= self and v.attacherJoint ~= nil and v.attacherVehicle == nil and self.allowedJointTypes[v.JointType] == true then
			local x,y,z = getWorldTranslation(v.attacherJoint);
			local distance = Utils.vector3Length(px-x, py-y, pz-z);
			if distance < nearestDistance then
				nearestNode =  v;
				break;
			end;
		end;
	end;

	return nearestNode;
end;